@@ -24,6 +24,7 @@
 #include <linux/pci_ids.h>
 #include <linux/power_supply.h>
 #include <linux/types.h>
+#include <linux/version.h>
 
 #include <acpi/battery.h>
 
@@ -253,7 +254,11 @@ static ssize_t charge_control_end_threshold_store(
 
 static DEVICE_ATTR_RW(charge_control_end_threshold);
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(6,2,0)
+static int librem_ec_battery_add(struct power_supply *battery, struct acpi_battery_hook *hook)
+#else
 static int librem_ec_battery_add(struct power_supply *battery)
+#endif
 {
 	// Librem EC only supports 1 battery
 	if (strcmp(battery->desc->name, "BAT0") != 0)
@@ -265,7 +270,11 @@ static int librem_ec_battery_add(struct power_supply *battery)
 	return 0;
 }
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(6,2,0)
+static int librem_ec_battery_remove(struct power_supply *battery, struct acpi_battery_hook *hook)
+#else
 static int librem_ec_battery_remove(struct power_supply *battery)
+#endif
 {
 	device_remove_file(&battery->dev, &dev_attr_charge_control_start_threshold);
 	device_remove_file(&battery->dev, &dev_attr_charge_control_end_threshold);
@@ -709,7 +718,11 @@ static int librem_ec_add(struct acpi_device *acpi_dev)
 }
 
 // Remove a Librem EC ACPI device
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(6,2,0)
+static void librem_ec_remove(struct acpi_device *acpi_dev)
+#else
 static int librem_ec_remove(struct acpi_device *acpi_dev)
+#endif
 {
 	struct librem_ec_data *data;
 
@@ -727,7 +740,9 @@ static int librem_ec_remove(struct acpi_device *acpi_dev)
 
 	librem_ec_get(data, "FINI");
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(6,2,0)
 	return 0;
+#endif
 }
 
 #ifdef CONFIG_PM_SLEEP
